==> pgmarket-1.3.3.tar.gz: pgmarket-1.3.3/firstpage.php <==
<?
/* index.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/
include("application.inc.php");
load_special_products(&$qid);
include($CFG->templatedir.$SESSION["lang"]."/index.ihtml");
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function load_special_products(&$qid) {
/* loads the list of special products */
	global $CFG;
	global $SESSION;
	global $weightunity;
	include ($CFG->global);

	$qid = db_query("
			SELECT p.* , b.name AS bname
			FROM products p JOIN brands b ON (p.brand_id = b.id)
			WHERE special_flag = 1
			ORDER BY special_level ASC
			");
}

?>

==> pgmarket-1.4rc1.tar.gz: pgmarket-1.4rc1/firstpage.php <==
<?
/* index.php (c) 2000 Ying Zhang (ying@zippydesign.com)
 *
 * TERMS OF USAGE:
 * This file was written and developed by Ying Zhang (ying@zippydesign.com)
 * for educational and demonstration purposes only.  You are hereby granted the 
 * rights to use, modify, and redistribute this file as you like.  The only
 * requirement is that you must retain this notice, without modifications, at
 * the top of your source code.  No warranties or guarantees are expressed or
 * implied. DO NOT use this code in a production environment without
 * understanding the limitations and weaknesses pretaining to or caused by the
 * use of these scripts, directly or indirectly. USE AT YOUR OWN RISK!
 */

/* (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

/******************************************************************************
 * MAIN
 *****************************************************************************/
include("application.inc.php");
load_special_products(&$qid);
include($CFG->templatedir.$SESSION["lang"]."/index.ihtml");
include("$CFG->templatedir"."footer.ihtml");

/******************************************************************************
 * FUNCTIONS
 *****************************************************************************/

function load_special_products(&$qid) {
/* loads the list of special products */
	global $CFG;
	global $SESSION;
	global $weightunity;
	include ($CFG->global);

	$qid = db_query("
			SELECT p.* , b.name AS bname
			FROM products p, brands b
			WHERE p.brand_id = b.id AND special_flag = 1
			ORDER BY special_level ASC
			");
}

?>
